"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _rollbar = _interopRequireDefault(require("./rollbar"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
var LaravelErrorHandler = /*#__PURE__*/function () {
  function LaravelErrorHandler() {
    _classCallCheck(this, LaravelErrorHandler);
  }
  _createClass(LaravelErrorHandler, null, [{
    key: "setup",
    value: function setup(callback) {
      // console.log("HttpErrorHandler - setup");
      // More callbacks can be added if necessary in the future
      if (!callback || !callback.onConnectionFail || !callback.onAPIFail) {
        console.warn('You must pass callback parameter to AppBootstrap.setup, with onConnectionFail and onAPIFail methods.');
      } else {
        LaravelErrorHandler.callback['onAPIFail'] = callback.onAPIFail;
        LaravelErrorHandler.callback['onConnectionFail'] = callback.onConnectionFail;
        LaravelErrorHandler.callback['errorCatcher'] = callback.errorCatcher; // Optional
      }
    }

    /**
     * Before send error to the view, change it and send it to Rollbar
     * @param error
     * @param method
     * @param url
     * @param sentBody
     * @returns {*}
     */
  }, {
    key: "handle",
    value: function handle(error, method, url, sentBody) {
      // Decorate error object
      if (error.status === 405 || error.status >= 500) {
        // Server error, don't show original - 405 or 5XX
        error.body = {
          error: ['Falha no servidor']
        };
        error.level = 'critical';
      } else if (error.status >= 400 && error.status <= 430) {
        // User payload error - 4XX (except 405)
        var body = JSON.parse(error.remote);
        if (body.error) {
          body.error = body.error.map(function (error) {
            return error.replace(/ *\[[^)]*\] */g, '');
          });
        }
        error.body = body;
        error.level = 'user'; // User error, don't send to Rollbar
      } else {
        // Another error (can be a error without status code)
        error.body = {
          error: [error.remote || error.message]
        };
        error.level = 'error';
      }
      // Http info
      error.method = method;
      error.url = url;
      error.sentBody = sentBody;
      if (error.message) {
        error.originalMessage = error.message;
      }

      // error.level !== 'user'
      // Handle error
      console.log("LaravelErrorHandler.handle", error.name, error.status);
      var statusCode = error.status ? String(error.status) : undefined;
      var errorName = error.name || statusCode;
      if (!errorName) {
        console.error("No error.name on LaravelErrorHandler.handle - error object:", error);
      }
      var handler = errorLibrary[error.name]; // error.name will work with laravel?
      if (handler) {
        if (handler.message) {
          error.message = handler.message;
        }
        if (handler.callback && LaravelErrorHandler.callback[handler.callback]) {
          LaravelErrorHandler.callback[handler.callback](error);
          error.sentToAnotherErrorHandler = true;
        }
        if (handler.level === null) {
          return error;
        } else {
          error.level = handler.level;
        }
      }

      // Send to rollbar or defined errorCatcher
      if (this.callback.errorCatcher) {
        this.callback.errorCatcher(error);
      } else {
        _rollbar.default[error.level](error);
      }
      error.sentToAnotherErrorHandler = true;
      return error;
    }
  }, {
    key: "mount",
    value:
    /**
     * Generate error object from the API response
     * @param response
     * @returns {Promise<T | never>}
     */
    function mount(response) {
      var error = {};
      error.status = response.status;
      error.response = response; // Save original response
      error.level = null;
      return response.text().then(function (data) {
        error.remote = data;
        throw error;
      });
    }
  }]);
  return LaravelErrorHandler;
}(); // Http errors that need a special handle.
var errorLibrary = {
  '400': {
    level: null //Don't send to rollbar
  },

  '404': {
    level: 'error',
    // Send to rollbar as error
    message: 'Não encontrado.',
    // Change de message to the view
    callback: 'onAPIFail' // Call onAPIFail callback
  },

  '500': {
    level: 'warning',
    message: 'Falha do servidor. Tente novamente.',
    callback: 'onConnectionFail'
  },
  '503': {
    level: 'warning',
    message: 'Falha do servidor. Tente novamente.',
    callback: 'onConnectionFail'
  },
  'ValidatorError': {
    level: 'critical',
    message: 'Um campo foi preenchido com valor não permitido.',
    callback: 'onAPIFail'
  },
  'MongoError': {
    level: 'warning',
    message: 'Falha de comunicação com o servidor.',
    callback: 'onConnectionFail'
  },
  'Failed to fetch': {
    level: 'warning',
    message: 'Falha de comunicação com o servidor.',
    callback: 'onConnectionFail'
  },
  'FetchError': {
    level: 'warning',
    message: 'Falha de comunicação com o servidor.',
    callback: 'onConnectionFail'
  }
};
LaravelErrorHandler.callback = {};
var _default = LaravelErrorHandler;
exports.default = _default;