"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _rollbar = _interopRequireDefault(require("./dependencies/rollbar"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
var rollbar;
var Rollbar = /*#__PURE__*/function () {
  function Rollbar() {
    _classCallCheck(this, Rollbar);
  }
  _createClass(Rollbar, null, [{
    key: "setup",
    value: function setup(accessToken, env, version, logOnDev, nodeEnv) {
      Rollbar.logOnDev = logOnDev === true;
      Rollbar.env = nodeEnv;
      if (Rollbar.env === 'production' || Rollbar.logOnDev) {
        (0, _rollbar.default)(accessToken, env, version, logOnDev === true, function (instance) {
          // console.log("rollbar setup done");
          rollbar = instance;
          Rollbar.sendPersonIfNeeded();
        });
      }
    }
  }, {
    key: "log",
    value: function log(message, payload, err, callback) {
      Rollbar.sendPersonIfNeeded();
      if (this.mustSend()) rollbar.info(message, payload, err, callback);else {
        console.warn('Rollbar.log > Log would be sent to rollbar');
        console.error(err, message, payload);
      }
    }
  }, {
    key: "info",
    value: function info(message, payload, err, callback) {
      Rollbar.sendPersonIfNeeded();
      if (this.mustSend()) rollbar.info(message, payload, err, callback);else {
        console.warn('Rollbar.info > Warning would be sent to rollbar');
        console.log(err, message, payload);
      }
    }
  }, {
    key: "debug",
    value: function debug(message, payload, err, callback) {
      Rollbar.sendPersonIfNeeded();
      if (this.mustSend()) rollbar.debug(message, payload, err, callback);else {
        console.warn('Rollbar.debug > Warning would be sent to rollbar');
        console.log(err, message, payload);
      }
    }
  }, {
    key: "warning",
    value: function warning(err, message, payload, callback) {
      Rollbar.sendPersonIfNeeded();
      if (this.mustSend()) rollbar.warning(message, payload, err, callback);else {
        console.warn('Rollbar.warning > Warning would be sent to rollbar');
        console.error(err, message, payload);
      }
    }
  }, {
    key: "error",
    value: function error(err, message, payload, callback) {
      Rollbar.sendPersonIfNeeded();
      if (this.mustSend()) rollbar.error(err, message, payload, callback);else {
        console.warn('Rollbar.error > Error would be sent to rollbar');
        console.error(err);
      }
    }
  }, {
    key: "critical",
    value: function critical(err, message, payload, callback) {
      Rollbar.sendPersonIfNeeded();
      if (this.mustSend()) rollbar.critical(err, message, payload, callback);else {
        console.warn('Rollbar.critical > Error would be sent to rollbar');
        console.error(err);
      }
    }
  }, {
    key: "setPerson",
    value: function setPerson(id, email, name) {
      Rollbar.personId = id;
      Rollbar.personEmail = email;
      Rollbar.personName = name;
      Rollbar.sendPersonIfNeeded();
    }
  }, {
    key: "sendPerson",
    value: function sendPerson() {
      if (!rollbar) return; //console.error("rollbar not defined at sendPerson?")

      rollbar.configure({
        payload: {
          person: {
            id: Rollbar.personId,
            username: Rollbar.personName,
            email: Rollbar.personEmail
          }
        }
      });
    }
  }, {
    key: "sendPersonIfNeeded",
    value: function sendPersonIfNeeded() {
      if (Rollbar.personId && !Rollbar.personSent) Rollbar.sendPerson();
    }

    /**
     * Tell if something must be sent to Rollbar
     * @returns {*|boolean}
     */
  }, {
    key: "mustSend",
    value: function mustSend() {
      return rollbar && (Rollbar.env !== 'development' || Rollbar.logOnDev);
    }
  }]);
  return Rollbar;
}();
_defineProperty(Rollbar, "personSent", void 0);
_defineProperty(Rollbar, "personId", void 0);
_defineProperty(Rollbar, "personEmail", void 0);
_defineProperty(Rollbar, "personName", void 0);
_defineProperty(Rollbar, "logOnDev", void 0);
_defineProperty(Rollbar, "env", void 0);
var _default = Rollbar;
exports.default = _default;